==> joplin_3.1.3%2Bds.orig.tar.xz: joplin-3.1.3/readme/apps/to-dos.md <==
# To-dos

Joplin supports both inline task lists and to-do notes. This document explains how to create and manage to-do notes.

## Creating a to-do

**On desktop:** Click the "new to-do" button above the note list.

**On mobile:** Open a notebook and click the "to-do" button in the "+" pop-up menu.

## Converting a task to a to-do

It's also possible to convert notes to to-dos and to-dos to notes.

**On desktop**, right-click a note, then click "Switch between note and to-do type":

**On mobile**, open a note, open the note action menu (opened by clicking thee "︙" button), and finally click "convert to todo" or "convert to note":

## Ordering to-dos

By default, incomplete to-dos are shown at the top of the note list. It's possible to change this.

**On desktop:** Open the "View" menu and uncheck "completed to-dos on top".

**On mobile:** Open the note list and click the "filter" button. Uncheck "completed to-dos on top".

It's also possible to hide incomplete to-dos entirely. As before, this can be done by un-checking "show completed to-dos" in the "View" menu on desktop and in the filter menu on mobile.


## Setting alarms

Joplin can be configured to show a notification for an incomplete to-dos. This is done differently on desktop and mobile.

**On desktop:** Click the alarm button in the note toolbar, enter a new date, then click "OK".

![](/images/desktop-set-alarm.png)

**On mobile:** Open the note actions menu, then click "set alarm".

Also see [the notifications documentation](https://joplinapp.org/help/apps/notifications) for how notifications are displayed.

==> joplin_3.4.1%2Bds.orig.tar.xz: joplin-3.4.1/readme/apps/to-dos.md <==
# To-dos

Joplin supports both inline task lists and to-do notes. This document explains how to create and manage to-do notes.

## Creating a to-do

**On desktop:** Click the "new to-do" button above the note list.

**On mobile:** Open a notebook and click the "to-do" button in the "+" pop-up menu.

## Converting a task to a to-do

It's also possible to convert notes to to-dos and to-dos to notes.

**On desktop**, right-click a note, then click "Switch between note and to-do type":

**On mobile**, open a note, open the note action menu (opened by clicking the "︙" button), and finally click "convert to todo" or "convert to note":

## Ordering to-dos

By default, incomplete to-dos are shown at the top of the note list. It's possible to change this.

**On desktop:** Open the "View" menu and uncheck "completed to-dos on top".

**On mobile:** Open the note list and click the "filter" button. Uncheck "completed to-dos on top".

It's also possible to hide incomplete to-dos entirely. As before, this can be done by un-checking "show completed to-dos" in the "View" menu on desktop and in the filter menu on mobile.


## Setting alarms

Joplin can be configured to show a notification for an incomplete to-dos. This is done differently on desktop and mobile.

**On desktop:** Click the alarm button in the note toolbar, enter a new date, then click "OK".

![](/images/desktop-set-alarm.png)

**On mobile:** Open the note actions menu, then click "set alarm".

Also see [the notifications documentation](https://joplinapp.org/help/apps/notifications) for how notifications are displayed.
